==> nan_scan-0.0.1.tar.gz: android/src/main/java/com/example/nan_scan/NanScanView.java <==
package com.example.nan_scan;

import android.app.Activity;
import android.content.Context;
import android.view.View;

import androidx.annotation.NonNull;

import org.jetbrains.annotations.NotNull;

import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

public class NanScanView implements PlatformView, ScanViewNew.CaptureListener, MethodChannel.MethodCallHandler {
    private View myView;

//    private Context mContext;
    private Context context;
    private Activity activity;
    private ActivityPluginBinding activityPluginBinding;
    private ScanViewNew scanViewNew;
    private NanParentView nanParentView;
    private MethodChannel channel;
    private boolean flashlight;
    private static BasicMessageChannel<Object> jumpMessageChannel;
    private BinaryMessenger binaryMessenger;

    NanScanView(BinaryMessenger binaryMessenger, Context context, Activity activity,ActivityPluginBinding activityPluginBinding,int viewId, Object args){
        this.context = context;
        this.activity = activity;
        this.activityPluginBinding = activityPluginBinding;
        this.binaryMessenger = binaryMessenger;
        channel = new MethodChannel(binaryMessenger, "nan_scan_method_"+viewId);
        channel.setMethodCallHandler(this);


        initForBinding(args);
    }

    private void initForBinding(Object args) {
        this.scanViewNew = new ScanViewNew(context, activity, activityPluginBinding,  args);
        this.scanViewNew.setCaptureListener(this);

//        this.scanDrawView = new ScanDrawView(context, activity, args);

        this.nanParentView = new NanParentView(context);
        this.nanParentView.addView(this.scanViewNew);
//        this.parentView.addView(this.scanDrawView);

//        jumpMessageChannel = new BasicMessageChannel<Object>(binaryMessenger, "nan_scan_channel", StandardMessageCodec.INSTANCE);
//        jumpMessageChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<Object>() {
//            @Override
//            public void onMessage(@Nullable @org.jetbrains.annotations.Nullable Object message, @NonNull @NotNull BasicMessageChannel.Reply<Object> reply) {
//                Map<Object, Object> arguments = (Map<Object, Object>) message;
//                String method = (String) arguments.get("method");
//                if (method.equals("toggleTorchMode")){
//                    scanViewNew.toggleTorchMode(!flashlight);
//                    flashlight = !flashlight;
//                }
//            }
//        });
    }


    @Override
    public View getView() {
        return this.nanParentView;
    }

    @Override
    public void dispose() {

    }

    @Override
    public void onCapture(String text) {
        channel.invokeMethod("onCaptured", text);
//        Map map = new HashMap();
//        map.put("method","onCaptured");
//        map.put("text",text);
//        jumpMessageChannel.send(map);
        pause();
    }

    private void pause() {
        this.scanViewNew.pause();
//        this.scanDrawView.pause();
    }
    private void resetStart(){
//        this.scanViewNew.previewStarted();
        this.scanViewNew._resume();
    }


    @Override
    public void onMethodCall(@NonNull @NotNull MethodCall call, @NonNull @NotNull MethodChannel.Result result) {
        if (call.method.equals("toggleTorchMode")){
            this.scanViewNew.toggleTorchMode(!flashlight);
            flashlight = !flashlight;
        }else if (call.method.equals("resetStart")){//重新开启扫码器
            resetStart();
        }else if (call.method.equals("disposeScan")){
            this.scanViewNew.dispose();
        }else if (call.method.equals("beginScan")){
//            this.scanViewNew.
        }
    }
}

==> nan_scan-0.0.2.tar.gz: android/src/main/java/com/example/nan_scan/NanScanView.java <==
package com.example.nan_scan;

import android.app.Activity;
import android.content.Context;
import android.view.View;

import androidx.annotation.NonNull;

import org.jetbrains.annotations.NotNull;

import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.BasicMessageChannel;
import io.flutter.plugin.common.BinaryMessenger;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.platform.PlatformView;

public class NanScanView implements PlatformView, NanScanCaptureAction, MethodChannel.MethodCallHandler {
    private View myView;

    private Context context;
    private Activity activity;
    private ActivityPluginBinding activityPluginBinding;
    private ScanViewNew scanViewNew;
    private NanParentView nanParentView;
    private MethodChannel channel;
    private boolean flashlight;
    private static BasicMessageChannel<Object> jumpMessageChannel;
    private BinaryMessenger binaryMessenger;

    NanScanView(BinaryMessenger binaryMessenger, Context context, Activity activity,ActivityPluginBinding activityPluginBinding,int viewId, Object args){
        this.context = context;
        this.activity = activity;
        this.activityPluginBinding = activityPluginBinding;
        this.binaryMessenger = binaryMessenger;
        channel = new MethodChannel(binaryMessenger, "nan_scan_method_"+viewId);
        channel.setMethodCallHandler(this);


        initForBinding(args);
    }

    private void initForBinding(Object args) {
        this.scanViewNew = new ScanViewNew(context, activity, activityPluginBinding,  args);
        this.scanViewNew.setScanCaptureAction(this);

//        this.scanDrawView = new ScanDrawView(context, activity, args);

        this.nanParentView = new NanParentView(context);
        this.nanParentView.addView(this.scanViewNew);
//        this.parentView.addView(this.scanDrawView);

//        jumpMessageChannel = new BasicMessageChannel<Object>(binaryMessenger, "nan_scan_channel", StandardMessageCodec.INSTANCE);
//        jumpMessageChannel.setMessageHandler(new BasicMessageChannel.MessageHandler<Object>() {
//            @Override
//            public void onMessage(@Nullable @org.jetbrains.annotations.Nullable Object message, @NonNull @NotNull BasicMessageChannel.Reply<Object> reply) {
//                Map<Object, Object> arguments = (Map<Object, Object>) message;
//                String method = (String) arguments.get("method");
//                if (method.equals("toggleTorchMode")){
//                    scanViewNew.toggleTorchMode(!flashlight);
//                    flashlight = !flashlight;
//                }
//            }
//        });
    }


    @Override
    public View getView() {
        return this.nanParentView;
    }

    @Override
    public void dispose() {

    }

    @Override
    public void onScanCapture(String text) {
        channel.invokeMethod("onCaptured", text);
//        Map map = new HashMap();
//        map.put("method","onCaptured");
//        map.put("text",text);
//        jumpMessageChannel.send(map);
        pause();
    }

    private void pause() {
        this.scanViewNew.pause();
//        this.scanDrawView.pause();
    }
    private void resetStart(){
//        this.scanViewNew.previewStarted();
        this.scanViewNew._resume();
    }


    @Override
    public void onMethodCall(@NonNull @NotNull MethodCall call, @NonNull @NotNull MethodChannel.Result result) {
        if (call.method.equals("toggleTorchMode")){
            this.scanViewNew.toggleTorchMode(!flashlight);
            flashlight = !flashlight;
        }else if (call.method.equals("resetStart")){//重新开启扫码器
            resetStart();
        }else if (call.method.equals("disposeScan")){
            this.scanViewNew.dispose();
        }else if (call.method.equals("beginScan")){
//            this.scanViewNew.
        }
    }
}
